@@ -46,7 +46,7 @@ class cjdgUser(base):
 
     def updateBatch(self, data):
         api_name = "user/batchmodifi"
-        return self.request(api_name, **data)
+        return self.request(api_name=api_name, json=data)
 
     def delete(self, data):
         api_name = "user/destroy"
